@@ -4,5 +4,6 @@ from .shell import shell_mode
 from .text import text_mode
 from .rewrite import rewrite_mode
 from .gitcommsg import gitcommsg_mode
+from .interactive import interactive_chat_session
 
-__all__ = ['chat_mode', 'code_mode', 'shell_mode', 'text_mode', 'rewrite_mode', 'gitcommsg_mode']
+__all__ = ['chat_mode', 'code_mode', 'shell_mode', 'text_mode', 'rewrite_mode', 'gitcommsg_mode', 'interactive_chat_session']
