@@ -1,7 +1,7 @@
 from ..formatters import COLORS
-from ..renderers import prettify_markdown, prettify_streaming_markdown
+from ..renderers import prettify_markdown, prettify_streaming_markdown, TERMINAL_RENDER_LOCK
 from ..ui import spinner
-from ...utils import enhance_prompt_with_web_search
+from ...utils import enhance_prompt_with_web_search, process_piped_input
 import sys
 import threading
 
@@ -13,43 +13,20 @@ def chat_mode(client, args, logger=None):
         args: The parsed command-line arguments
         logger: Optional logger instance
     """
+    # Get the prompt
+    if args.prompt is None:
+        try:
+            print("Enter your prompt: ", end='')
+            prompt = input()
+        except KeyboardInterrupt:
+            print("\nInput cancelled by user. Exiting gracefully.")
+            sys.exit(130)
+    else:
+        prompt = args.prompt
+    
     # Handle pipe mode
     if args.pipe:
-        # Read input from stdin
-        stdin_content = sys.stdin.read().strip()
-        
-        # Get the prompt - either use provided one or ask user
-        if args.prompt is None:
-            try:
-                print("Enter your prompt (use {} as placeholder for stdin): ", end='')
-                prompt = input()
-            except KeyboardInterrupt:
-                print("\nInput cancelled by user. Exiting gracefully.")
-                sys.exit(130)
-        else:
-            prompt = args.prompt
-        
-        # Replace the placeholder in the prompt with stdin content
-        placeholder = "{}"
-        
-        # Check if the placeholder exists in the prompt
-        if placeholder not in prompt:
-            print(f"{COLORS['yellow']}Warning: Placeholder '{placeholder}' not found in prompt. Appending stdin content to the end.{COLORS['reset']}")
-            prompt = f"{prompt} {stdin_content}"
-        else:
-            prompt = prompt.replace(placeholder, stdin_content)
-    # Handle regular chat mode
-    else:
-        # Get the prompt
-        if args.prompt is None:
-            try:
-                print("Enter your prompt: ", end='')
-                prompt = input()
-            except KeyboardInterrupt:
-                print("\nInput cancelled by user. Exiting gracefully.")
-                sys.exit(130)
-        else:
-            prompt = args.prompt
+        prompt = process_piped_input(prompt, logger=logger)
     
     # Log the user message if logging is enabled
     if logger:
@@ -59,8 +36,32 @@ def chat_mode(client, args, logger=None):
     if args.web_search:
         try:
             original_prompt = prompt
-            prompt = enhance_prompt_with_web_search(prompt, logger=logger)
-            print("Enhanced input with web search results.")
+            
+            # Start spinner for web search
+            stop_spinner = threading.Event()
+            spinner_thread = threading.Thread(
+                target=spinner, 
+                args=("Searching the web for information...",), 
+                kwargs={"stop_event": stop_spinner, "color": COLORS['cyan']}
+            )
+            spinner_thread.daemon = True
+            spinner_thread.start()
+            
+            try:
+                prompt = enhance_prompt_with_web_search(prompt, logger=logger)
+                # Stop the spinner
+                stop_spinner.set()
+                spinner_thread.join()
+                # Clear the spinner line completely
+                with TERMINAL_RENDER_LOCK:
+                    sys.stdout.write("\r" + " " * 100 + "\r")
+                    sys.stdout.flush()
+                    print("Enhanced input with web search results.")
+            except Exception as e:
+                # Stop the spinner before re-raising
+                stop_spinner.set()
+                spinner_thread.join()
+                raise e
             
             # Log the enhanced prompt if logging is enabled
             if logger:
@@ -70,17 +71,21 @@ def chat_mode(client, args, logger=None):
             print(f"{COLORS['yellow']}Warning: Failed to enhance prompt with web search: {str(e)}{COLORS['reset']}")
             # Continue with the original prompt if web search fails
         
-    # Create messages array with preprompt if available
-    messages = None
-    if args.preprompt:
-        # Log the system message if logging is enabled
-        if logger:
-            logger.log("system", args.preprompt)
-            
-        messages = [
-            {"role": "system", "content": args.preprompt},
-            {"role": "user", "content": prompt}
-        ]
+    # Create messages array with system prompt
+    default_system_prompt = "You are a helpful assistant."
+    if args.prettify or args.stream_prettify:
+        default_system_prompt += " You can use markdown formatting in your responses where appropriate."
+    
+    system_prompt = args.preprompt if args.preprompt else default_system_prompt
+    
+    # Log the system message if logging is enabled
+    if logger:
+        logger.log("system", system_prompt)
+        
+    messages = [
+        {"role": "system", "content": system_prompt},
+        {"role": "user", "content": prompt}
+    ]
     
     # Set default streaming behavior based on --no-stream and --prettify arguments
     should_stream = not args.no_stream and not args.prettify
@@ -125,11 +130,14 @@ def chat_mode(client, args, logger=None):
         # On first content, stop the spinner 
         if not first_content_received and stop_spinner_func:
             first_content_received = True
-            # Stop the spinner
-            stop_spinner_func()
-            # Ensure spinner message is cleared with an extra blank line
-            sys.stdout.write("\r" + " " * 100 + "\r")
-            sys.stdout.flush()
+            
+            # Use lock to prevent terminal rendering conflicts
+            with TERMINAL_RENDER_LOCK:
+                # Stop the spinner
+                stop_spinner_func()
+                # Ensure spinner message is cleared with an extra blank line
+                sys.stdout.write("\r" + " " * 100 + "\r")
+                sys.stdout.flush()
         
         # Call the original callback to update the display
         if original_callback:
@@ -161,7 +169,8 @@ def chat_mode(client, args, logger=None):
         
     # Handle non-stream response or regular prettify
     if (args.no_stream or args.prettify) and response:
-        if args.prettify:
-            prettify_markdown(response, args.renderer)
-        else:
-            print(response) 
\ No newline at end of file
+        with TERMINAL_RENDER_LOCK:
+            if args.prettify:
+                prettify_markdown(response, args.renderer)
+            else:
+                print(response) 
\ No newline at end of file
