@@ -1,7 +1,7 @@
 from ..formatters import COLORS
-from ..renderers import prettify_markdown, prettify_streaming_markdown, has_markdown_renderer, show_available_renderers
-from ..ui import spinner
-from ...utils import enhance_prompt_with_web_search
+from ..renderers import prettify_markdown, prettify_streaming_markdown, has_markdown_renderer, show_available_renderers, TERMINAL_RENDER_LOCK
+from ..ui import spinner, copy_to_clipboard
+from ...utils import enhance_prompt_with_web_search, process_piped_input
 import sys
 import threading
 
@@ -97,6 +97,10 @@ def code_mode(client, args, logger=None):
     else:
         prompt = args.prompt
     
+    # Apply piped input if --pipe is enabled
+    if args.pipe:
+        prompt = process_piped_input(prompt, logger=logger)
+    
     # Log the user prompt if logging is enabled
     if logger:
         logger.log("user", prompt)
@@ -105,8 +109,32 @@ def code_mode(client, args, logger=None):
     if args.web_search:
         try:
             original_prompt = prompt
-            prompt = enhance_prompt_with_web_search(prompt, logger=logger, disable_citations=True)
-            print("Enhanced input with web search results.")
+            
+            # Start spinner for web search
+            stop_spinner = threading.Event()
+            spinner_thread = threading.Thread(
+                target=spinner, 
+                args=("Searching the web for information...",), 
+                kwargs={"stop_event": stop_spinner, "color": COLORS['cyan']}
+            )
+            spinner_thread.daemon = True
+            spinner_thread.start()
+            
+            try:
+                prompt = enhance_prompt_with_web_search(prompt, logger=logger, disable_citations=True)
+                # Stop the spinner
+                stop_spinner.set()
+                spinner_thread.join()
+                # Clear the spinner line completely
+                with TERMINAL_RENDER_LOCK:
+                    sys.stdout.write("\r" + " " * 100 + "\r")
+                    sys.stdout.flush()
+                    print("Enhanced input with web search results.")
+            except Exception as e:
+                # Stop the spinner before re-raising
+                stop_spinner.set()
+                spinner_thread.join()
+                raise e
             
             # Log the enhanced prompt if logging is enabled
             if logger:
@@ -184,11 +212,14 @@ def code_mode(client, args, logger=None):
         # On first content, stop the spinner 
         if not first_content_received and stop_spinner_func:
             first_content_received = True
-            # Stop the spinner
-            stop_spinner_func()
-            # Ensure spinner message is cleared with an extra blank line
-            sys.stdout.write("\r" + " " * 100 + "\r")
-            sys.stdout.flush()
+            
+            # Use lock to prevent terminal rendering conflicts
+            with TERMINAL_RENDER_LOCK:
+                # Stop the spinner
+                stop_spinner_func()
+                # Ensure spinner message is cleared with an extra blank line
+                sys.stdout.write("\r" + " " * 100 + "\r")
+                sys.stdout.flush()
         
         # Call the original callback to update the display
         if original_callback:
@@ -270,9 +301,14 @@ def code_mode(client, args, logger=None):
         
     # Print non-streamed output if needed
     if generated_code and not should_stream:
-        if use_regular_prettify:
-            print("\nGenerated code:")
-            prettify_markdown(generated_code, args.renderer)
-        else:
-            # Should only happen if --no-stream was used without prettify
-            print(f"\nGenerated code:\n{generated_code}") 
\ No newline at end of file
+        with TERMINAL_RENDER_LOCK:
+            if use_regular_prettify:
+                print("\nGenerated code:")
+                prettify_markdown(generated_code, args.renderer)
+            else:
+                # Should only happen if --no-stream was used without prettify
+                print(f"\nGenerated code:\n{generated_code}")
+            
+    # Offer to copy to clipboard
+    if generated_code and not args.no_stream:
+        copy_to_clipboard(generated_code) 
\ No newline at end of file
