@@ -1,11 +1,10 @@
 import sys
-import platform
 import threading
 import time
 from ..formatters import COLORS
-from ..renderers import prettify_markdown, prettify_streaming_markdown
-from ..ui import get_multiline_input, spinner
-from ...utils import enhance_prompt_with_web_search
+from ..renderers import prettify_markdown, prettify_streaming_markdown, TERMINAL_RENDER_LOCK
+from ..ui import get_multiline_input, spinner, copy_to_clipboard
+from ...utils import enhance_prompt_with_web_search, process_piped_input
 
 # System prompt for rewriting text
 REWRITE_SYSTEM_PROMPT = """You are an expert text editor and rewriter. Your task is to rewrite the user's text to improve readability and flow while carefully preserving the original meaning, tone, and style.
@@ -71,28 +70,6 @@ ORIGINAL: "The user interface, which is built using React, Redux, and various ot
 BETTER: "The React/Redux user interface needs redesigning to accommodate our planned new features."
 """
 
-def get_terminal_input():
-    """Get input from terminal in a cross-platform way, even when stdin is redirected."""
-    if platform.system() == 'Windows':
-        # Windows-specific solution
-        try:
-            import msvcrt
-            sys.stdout.flush()
-            # Wait for a keypress
-            char = msvcrt.getch().decode('utf-8').lower()
-            print(char)  # Echo the character
-            return char
-        except ImportError:
-            # Fallback if msvcrt is not available
-            return None
-    else:
-        # Unix-like systems (Linux, macOS)
-        try:
-            with open('/dev/tty', 'r') as tty:
-                return tty.readline().strip().lower()
-        except (IOError, OSError):
-            return None
-
 def rewrite_mode(client, args, logger=None):
     """Handle the text rewriting mode.
     
@@ -101,14 +78,17 @@ def rewrite_mode(client, args, logger=None):
         args: The parsed command-line arguments
         logger: Optional logger instance
     """
-    # Determine the input source (stdin pipe, command-line argument, or multiline input)
-    if not sys.stdin.isatty():
+    # Check if using --pipe flag with a specific placeholder
+    if args.pipe and args.prompt:
+        input_text = process_piped_input(args.prompt, logger=logger)
+    # Normal rewrite mode functionality (direct stdin piping without --pipe flag)
+    elif not sys.stdin.isatty():
         # Read from stdin if data is piped
         input_text = sys.stdin.read().strip()
         
-        # If stdin is empty but prompt is provided, use the prompt
-        if not input_text and args.prompt:
-            input_text = args.prompt
+        # If prompt is also provided, append it to the piped input
+        if args.prompt:
+            input_text = f"{input_text}\n\n{args.prompt}"
     elif args.prompt:
         # Use the command-line argument if provided
         input_text = args.prompt
@@ -130,8 +110,32 @@ def rewrite_mode(client, args, logger=None):
     if args.web_search:
         try:
             original_text = input_text
-            input_text = enhance_prompt_with_web_search(input_text, logger=logger)
-            print("Enhanced input with web search results.")
+            
+            # Start spinner for web search
+            stop_spinner = threading.Event()
+            spinner_thread = threading.Thread(
+                target=spinner, 
+                args=("Searching the web for information...",), 
+                kwargs={"stop_event": stop_spinner, "color": COLORS['cyan']}
+            )
+            spinner_thread.daemon = True
+            spinner_thread.start()
+            
+            try:
+                input_text = enhance_prompt_with_web_search(input_text, logger=logger)
+                # Stop the spinner
+                stop_spinner.set()
+                spinner_thread.join()
+                # Clear the spinner line completely
+                with TERMINAL_RENDER_LOCK:
+                    sys.stdout.write("\r" + " " * 100 + "\r")
+                    sys.stdout.flush()
+                    print("Enhanced input with web search results.")
+            except Exception as e:
+                # Stop the spinner before re-raising
+                stop_spinner.set()
+                spinner_thread.join()
+                raise e
             
             # Log the enhanced input if logging is enabled
             if logger:
@@ -194,11 +198,14 @@ def rewrite_mode(client, args, logger=None):
         # On first content, stop the spinner 
         if not first_content_received and stop_spinner_func:
             first_content_received = True
-            # Stop the spinner
-            stop_spinner_func()
-            # Ensure spinner message is cleared with an extra blank line
-            sys.stdout.write("\r" + " " * 100 + "\r\n")
-            sys.stdout.flush()
+            
+            # Use lock to prevent terminal rendering conflicts
+            with TERMINAL_RENDER_LOCK:
+                # Stop the spinner
+                stop_spinner_func()
+                # Ensure spinner message is cleared with an extra blank line
+                sys.stdout.write("\r" + " " * 100 + "\r\n")
+                sys.stdout.flush()
         
         # Call the original callback to update the display
         if original_callback:
@@ -238,30 +245,12 @@ def rewrite_mode(client, args, logger=None):
         
     # Handle non-stream response or regular prettify
     if (args.no_stream or args.prettify) and response:
-        if args.prettify:
-            prettify_markdown(response, args.renderer)
-        else:
-            print(response)
+        with TERMINAL_RENDER_LOCK:
+            if args.prettify:
+                prettify_markdown(response, args.renderer)
+            else:
+                print(response)
             
     # Offer to copy to clipboard if not in a redirected output
-    if not args.no_stream and sys.stdout.isatty():
-        try:
-            # Make sure to flush output before asking for input
-            # Make the prompt more visible with colors and formatting
-            clipboard_prompt = f"{COLORS['cyan']}{COLORS['bold']}Copy to clipboard? (y/n){COLORS['reset']} "
-            print(clipboard_prompt, end="")
-            sys.stdout.flush()
-            
-            # Cross-platform terminal input
-            answer = get_terminal_input()
-            
-            if answer == 'y':
-                try:
-                    import pyperclip
-                    pyperclip.copy(response)
-                    print(f"{COLORS['green']}Copied to clipboard.{COLORS['reset']}")
-                except ImportError:
-                    print(f"{COLORS['yellow']}pyperclip not installed. Try: pip install \"ngpt[clipboard]\" {COLORS['reset']}")
-            
-        except (KeyboardInterrupt, EOFError):
-            pass 
\ No newline at end of file
+    if not args.no_stream and response:
+        copy_to_clipboard(response) 
\ No newline at end of file
