@@ -3,8 +3,12 @@ import shutil
 import subprocess
 import tempfile
 import sys
+import threading
 from .formatters import COLORS
 
+# Global lock for terminal rendering to prevent race conditions
+TERMINAL_RENDER_LOCK = threading.Lock()
+
 # Try to import markdown rendering libraries
 try:
     import rich
@@ -308,63 +312,65 @@ def prettify_streaming_markdown(renderer='rich', is_interactive=False, header_te
             # Check if this is the final update (complete flag)
             is_complete = kwargs.get('complete', False)
             
-            # Start live display on first content
-            if first_update:
-                first_update = False
-                # Let the spinner's clean_exit handle the cleanup
-                # No additional cleanup needed here
-                live.start()
-            
-            # Update content in live display
-            if is_interactive and header_text:
-                # Update the panel content - for streaming, only show the last portion that fits in display_height
-                if not is_complete:
-                    # Calculate approximate lines needed (rough estimation)
-                    content_lines = content.count('\n') + 1
-                    available_height = display_height - 4  # Account for panel borders and padding
-                    
-                    if content_lines > available_height:
-                        # If content is too big, show only the last part that fits
-                        lines = content.split('\n')
-                        truncated_content = '\n'.join(lines[-available_height:])
-                        md_obj.renderable = Markdown(truncated_content)
+            # Use lock to prevent terminal rendering conflicts
+            with TERMINAL_RENDER_LOCK:
+                # Start live display on first content
+                if first_update:
+                    first_update = False
+                    # Let the spinner's clean_exit handle the cleanup
+                    # No additional cleanup needed here
+                    live.start()
+                
+                # Update content in live display
+                if is_interactive and header_text:
+                    # Update the panel content - for streaming, only show the last portion that fits in display_height
+                    if not is_complete:
+                        # Calculate approximate lines needed (rough estimation)
+                        content_lines = content.count('\n') + 1
+                        available_height = display_height - 4  # Account for panel borders and padding
+                        
+                        if content_lines > available_height:
+                            # If content is too big, show only the last part that fits
+                            lines = content.split('\n')
+                            truncated_content = '\n'.join(lines[-available_height:])
+                            md_obj.renderable = Markdown(truncated_content)
+                        else:
+                            md_obj.renderable = Markdown(content)
                     else:
                         md_obj.renderable = Markdown(content)
-                else:
-                    md_obj.renderable = Markdown(content)
-                
-                live.update(md_obj)
-            else:
-                # Same logic for non-interactive mode
-                if not is_complete:
-                    # Calculate approximate lines needed
-                    content_lines = content.count('\n') + 1
-                    available_height = display_height - 4  # Account for panel borders and padding
                     
-                    if content_lines > available_height:
-                        # If content is too big, show only the last part that fits
-                        lines = content.split('\n')
-                        truncated_content = '\n'.join(lines[-available_height:])
-                        md_obj.renderable = Markdown(truncated_content)
+                    live.update(md_obj)
+                else:
+                    # Same logic for non-interactive mode
+                    if not is_complete:
+                        # Calculate approximate lines needed
+                        content_lines = content.count('\n') + 1
+                        available_height = display_height - 4  # Account for panel borders and padding
+                        
+                        if content_lines > available_height:
+                            # If content is too big, show only the last part that fits
+                            lines = content.split('\n')
+                            truncated_content = '\n'.join(lines[-available_height:])
+                            md_obj.renderable = Markdown(truncated_content)
+                        else:
+                            md_obj.renderable = Markdown(content)
                     else:
                         md_obj.renderable = Markdown(content)
-                else:
-                    md_obj.renderable = Markdown(content)
+                        
+                    live.update(md_obj)
                     
-                live.update(md_obj)
+                # Ensure the display refreshes with new content
+                live.refresh()
                 
-            # Ensure the display refreshes with new content
-            live.refresh()
-            
-            # If streaming is complete, stop the live display
-            if is_complete:
-                try:
-                    # Just stop the live display when complete - no need to redisplay content
-                    live.stop()
-                except Exception as e:
-                    # Fallback if something goes wrong
-                    sys.stderr.write(f"\nError stopping live display: {str(e)}\n")
-                    sys.stderr.flush()
+                # If streaming is complete, stop the live display
+                if is_complete:
+                    try:
+                        # Just stop the live display when complete - no need to redisplay content
+                        live.stop()
+                    except Exception as e:
+                        # Fallback if something goes wrong
+                        sys.stderr.write(f"\nError stopping live display: {str(e)}\n")
+                        sys.stderr.flush()
         
         # Define a function to set up and start the spinner
         def setup_spinner(stop_event, message="Waiting for AI response...", color=COLORS['cyan']):
