@@ -1,6 +1,7 @@
 import sys
 import time
 import shutil
+import platform
 from .formatters import COLORS
 
 # Optional imports for enhanced UI
@@ -116,10 +117,6 @@ def get_multiline_input():
     editor_app, has_editor = create_multiline_editor()
     
     if has_editor and editor_app:
-        print("\033[94m\033[1m" + "Multi-line Input Mode" + "\033[0m")
-        print("Press Ctrl+D to submit, Ctrl+C to exit")
-        print("Use arrow keys to navigate, Enter for new line")
-        
         try:
             prompt = editor_app.run()
             if not prompt or not prompt.strip():
@@ -155,6 +152,102 @@ def get_multiline_input():
             print("\nInput cancelled by user. Exiting gracefully.")
             return None
 
+def get_terminal_input():
+    """Get input from terminal in a cross-platform way, even when stdin is redirected."""
+    if platform.system() == 'Windows':
+        # Windows-specific solution
+        try:
+            import msvcrt
+            sys.stdout.flush()
+            
+            # Wait for a complete line (including Enter key)
+            input_chars = []
+            while True:
+                # Get a character
+                char = msvcrt.getch()
+                
+                # If it's Enter (CR or LF), break the loop
+                if char in [b'\r', b'\n']:
+                    print()  # Move to the next line after Enter
+                    break
+                    
+                # If it's backspace, handle it
+                if char == b'\x08':
+                    if input_chars:
+                        # Remove the last character
+                        input_chars.pop()
+                        # Erase the character on screen (backspace + space + backspace)
+                        sys.stdout.write('\b \b')
+                        sys.stdout.flush()
+                    continue
+                    
+                # For regular characters, add to input and echo
+                try:
+                    char_decoded = char.decode('utf-8').lower()
+                    input_chars.append(char_decoded)
+                    print(char_decoded, end='', flush=True)  # Echo the character without newline
+                except UnicodeDecodeError:
+                    # Skip characters that can't be decoded
+                    continue
+            
+            # Join all characters and return
+            return ''.join(input_chars).strip().lower()
+        except ImportError:
+            # Fallback if msvcrt is not available
+            return None
+    else:
+        # Unix-like systems (Linux, macOS)
+        try:
+            with open('/dev/tty', 'r') as tty:
+                return tty.readline().strip().lower()
+        except (IOError, OSError):
+            return None
+
+def copy_to_clipboard(content, prompt_message=None, skip_confirmation=False):
+    """Copy content to clipboard with user confirmation.
+    
+    Args:
+        content: The text content to copy to clipboard
+        prompt_message: Optional custom message for the prompt (default: "Copy to clipboard? (y/n)")
+        skip_confirmation: When True, skips the confirmation prompt and copies directly
+        
+    Returns:
+        bool: True if copied to clipboard successfully, False otherwise
+    """
+    # Only prompt if stdout is connected to a terminal
+    if not sys.stdout.isatty():
+        return False
+        
+    try:
+        # Skip confirmation if requested
+        if skip_confirmation:
+            answer = 'y'
+        else:
+            # Default prompt message
+            if prompt_message is None:
+                prompt_message = "Copy to clipboard? (y/n)"
+                
+            # Make the prompt more visible with colors and formatting
+            clipboard_prompt = f"{COLORS['cyan']}{COLORS['bold']}{prompt_message}{COLORS['reset']} "
+            print(clipboard_prompt, end="")
+            sys.stdout.flush()
+            
+            # Cross-platform terminal input
+            answer = get_terminal_input()
+        
+        if answer == 'y':
+            try:
+                import pyperclip
+                pyperclip.copy(content)
+                print(f"{COLORS['green']}Copied to clipboard.{COLORS['reset']}")
+                return True
+            except ImportError:
+                print(f"{COLORS['yellow']}pyperclip not installed. Try: pip install \"ngpt[clipboard]\" {COLORS['reset']}")
+                return False
+        return False
+    except (KeyboardInterrupt, EOFError):
+        return False
+
 def spinner(message, duration=5, spinner_chars="⣾⣽⣻⢿⡿⣟⣯⣷", color=None, stop_event=None, clean_exit=False):
     """Display a spinner animation with a message.
     
