@@ -27,6 +27,7 @@ from .web_search import (
     get_web_search_results,
     format_web_search_results_for_prompt
 )
+from .pipe import process_piped_input
 
 __all__ = [
     "create_logger", "Logger",
@@ -35,5 +36,6 @@ __all__ = [
     "load_cli_config", "set_cli_config_option", "get_cli_config_option", 
     "unset_cli_config_option", "apply_cli_config", "list_cli_config_options",
     "CLI_CONFIG_OPTIONS", "get_cli_config_dir", "get_cli_config_path",
-    "enhance_prompt_with_web_search", "get_web_search_results", "format_web_search_results_for_prompt"
+    "enhance_prompt_with_web_search", "get_web_search_results", "format_web_search_results_for_prompt",
+    "process_piped_input"
 ]
